@@ -8,13 +8,8 @@ type Platform struct {
 	// Region specifies the Azure region where the cluster will be created.
 	Region string `json:"region"`
 
-	// BaseDomainResourceGroupName specifies the resource group where the azure DNS zone for the base domain is found
+	// BaseDomainResourceGroupName specifies the resource group where the Azure DNS zone for the base domain is found.
 	BaseDomainResourceGroupName string `json:"baseDomainResourceGroupName,omitempty"`
-
-	// UserTags specifies additional tags for Azure resources created for the cluster.
-	// +optional
-	UserTags map[string]string `json:"userTags,omitempty"`
-
 	// DefaultMachinePlatform is the default configuration used when
 	// installing on Azure for machine pools which do not define their own
 	// platform configuration.
